==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/cy-GB/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Fedrith y defnyddiwr yma mewngofnodi',
    'activated_disabled_help_text' => 'Nid yw\'n bosib newid statws eich cyfrif.',
    'assets_user'       => 'Asedu wedi aseinio i :name',
    'bulk_update_warn'	=> 'Rydych am golygu manylion :user_count o ddefnyddwyr. Nodwch, nid yw\'n bosib i chi newid manylion eich cyfrif yma. Rhaid i chi golygu manylion eich cyfrif yn unigol.',
    'bulk_update_help'	=> 'Mae\'r ffurflen hon yn caniatáu ichi ddiweddaru nifer o defnyddwyr ar unwaith. Llenwch y meysydd sydd angen i chi eu newid yn unig. Bydd unrhyw bwlch a adewir yn wag yn aros yr un fath.',
    'current_assets'    => 'Asedau wedi aseinio ar hyn o bryd i\'r defnyddiwr yma',
    'clone'             => 'Dyblygu Defnyddiwr',
    'contact_user'      => 'Cyswllt :name',
    'edit'              => 'Golygu Defnyddiwr',
    'filetype_info'     => 'Math o ffeiliau a caniateir yw png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, a rar.',
    'history_user'      => 'Hanes ar gyfer :name',
    'info'				=> 'Gwybodaeth',
    'restore_user'		=> 'Cliciwch yma yw adfer.',
    'last_login'        => 'Mewngofnodi Diwethaf',
    'ldap_config_text'  => 'Gweler Gweinyddiaeth > Gosodiadau am gosodiadau LDAP. Mae\'r lleoliad (dewisol) yn cael ei osod am unrhyw defnyddwyr sydd yn cael ei mewnforio.',
    'print_assigned'    => 'Argraffu Asedau',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Meddalwedd allan i :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Gweld Defnyddiwr :name',
    'usercsv'           => 'Ffeil CSV',
    'two_factor_admin_optin_help' => 'Mae eich gosodiadau admin yn caniatau gorfodaeth dewisol o dilysiant dau-factor.  ',
    'two_factor_enrolled' => 'Dyfais D2F Wedi Ymuno ',
    'two_factor_active'   => 'D2F Weithredol ',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/cy-GB/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Fedrith y defnyddiwr yma mewngofnodi',
    'activated_disabled_help_text' => 'Nid yw\'n bosib newid statws eich cyfrif.',
    'assets_user'       => 'Asedu wedi aseinio i :name',
    'bulk_update_warn'	=> 'Rydych am golygu manylion :user_count o ddefnyddwyr. Nodwch, nid yw\'n bosib i chi newid manylion eich cyfrif yma. Rhaid i chi golygu manylion eich cyfrif yn unigol.',
    'bulk_update_help'	=> 'Mae\'r ffurflen hon yn caniatáu ichi ddiweddaru nifer o defnyddwyr ar unwaith. Llenwch y meysydd sydd angen i chi eu newid yn unig. Bydd unrhyw bwlch a adewir yn wag yn aros yr un fath.',
    'current_assets'    => 'Asedau wedi aseinio ar hyn o bryd i\'r defnyddiwr yma',
    'clone'             => 'Dyblygu Defnyddiwr',
    'contact_user'      => 'Cyswllt :name',
    'edit'              => 'Golygu Defnyddiwr',
    'filetype_info'     => 'Math o ffeiliau a caniateir yw png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, a rar.',
    'history_user'      => 'Hanes ar gyfer :name',
    'info'				=> 'Gwybodaeth',
    'restore_user'		=> 'Cliciwch yma yw adfer.',
    'last_login'        => 'Mewngofnodi Diwethaf',
    'ldap_config_text'  => 'Gweler Gweinyddiaeth > Gosodiadau am gosodiadau LDAP. Mae\'r lleoliad (dewisol) yn cael ei osod am unrhyw defnyddwyr sydd yn cael ei mewnforio.',
    'print_assigned'    => 'Argraffu Asedau',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Meddalwedd allan i :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Gweld Defnyddiwr :name',
    'usercsv'           => 'Ffeil CSV',
    'two_factor_admin_optin_help' => 'Mae eich gosodiadau admin yn caniatau gorfodaeth dewisol o dilysiant dau-factor.  ',
    'two_factor_enrolled' => 'Dyfais D2F Wedi Ymuno ',
    'two_factor_active'   => 'D2F Weithredol ',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
